test Package
============

:mod:`test` Package
-------------------

.. automodule:: stoqlib.domain.test
    :members:
    :show-inheritance:

:mod:`domaintest` Module
------------------------

.. automodule:: stoqlib.domain.test.domaintest
    :members:
    :show-inheritance:

